@@ -96,7 +96,7 @@ def reflectivity_fresnel(refraction_index_delta=1e-5,refraction_index_beta=0.0,\
     # ;
     #
     theta1 = grazing_angle_mrad*1e-3     # in rad
-    rough1 = roughness_rms_A*1e-8 # in cm
+    rough1 = roughness_rms_A
 
     # ; epsi = 1 - alpha - i gamma
     # alpha = 2.0D0*k*f1
@@ -222,7 +222,7 @@ def f1f2_calc(descriptor,energy,theta=3.0e-3,F=0,density=None,rough=0.0):
     elif F == 4: # F=4  returns betaf  [n = 1 -delta -i beta]
         out = numpy.zeros_like(energy)
         for i,ienergy in enumerate(energy):
-            out[i] = (1e0-xraylib.Refractive_Index_Im(symbol,1e-3*ienergy,density))
+            out[i] = xraylib.Refractive_Index_Im(symbol,1e-3*ienergy,density)
     elif F == 5: # F=5  returns Photoelectric linear absorption coefficient
         out = numpy.zeros_like(energy)
         for i,ienergy in enumerate(energy):
@@ -263,6 +263,7 @@ def f1f2_calc(descriptor,energy,theta=3.0e-3,F=0,density=None,rough=0.0):
         rs,rp,runp = interface_reflectivity(alpha,gamma,theta)
 
         if rough != 0:
+            rough *= 1e-8 # to cm
             debyewaller = numpy.exp( -( 4.0 * numpy.pi * numpy.sin(theta) * rough / wavelength)**2)
         else:
             debyewaller = 1.0
@@ -317,8 +318,8 @@ def f1f2_calc_mix(descriptor,energy,theta=3.0e-3,F=0,density=None,rough=0.0):
     f1 = numpy.zeros_like(energy)
     f2 = numpy.zeros_like(energy)
     for i,zi in enumerate(zetas):
-        f1i = f1f2_calc(xraylib.AtomicNumberToSymbol(zi),1e-3*energy,theta,F=1)
-        f2i = f1f2_calc(xraylib.AtomicNumberToSymbol(zi),1e-3*energy,theta,F=2)
+        f1i = f1f2_calc(xraylib.AtomicNumberToSymbol(zi), energy,theta,F=1)
+        f2i = f1f2_calc(xraylib.AtomicNumberToSymbol(zi), energy,theta,F=2)
         f1 += f1i * weights[i]
         f2 += f2i * weights[i]
 
@@ -365,6 +366,7 @@ def f1f2_calc_mix(descriptor,energy,theta=3.0e-3,F=0,density=None,rough=0.0):
     rs,rp,runp = interface_reflectivity(alpha,gamma,theta)
 
     if rough != 0:
+        rough *= 1e-8 # to cm
         debyewaller = numpy.exp( -( 4.0 * numpy.pi * numpy.sin(theta) * rough / wavelength)**2)
     else:
         debyewaller = 1.0
@@ -556,9 +558,9 @@ def xpower_calc(energies=numpy.linspace(1000.0,50000.0,100),source=numpy.ones(10
     txt = ""
     txt += "*************************** power results ******************\n"
     if energies[0] != energies[-1]:
-        txt += "  Source energy: start=%f keV, end=%f keV, points=%d \n"%(energies[0],energies[-1],energies.size)
+        txt += "  Source energy: start=%f eV, end=%f eV, points=%d \n"%(energies[0],energies[-1],energies.size)
     else:
-        txt += "  Source energy: %f keV\n"%(energies[0])
+        txt += "  Source energy: %f eV\n"%(energies[0])
     txt += "  Number of optical elements: %d\n"%(nelem)
 
     if energies[0] != energies[-1]:
@@ -1814,7 +1816,7 @@ if __name__ == "__main__":
     # parsers (not used, we use xraylib instead)
     #
 
-    aw1 = parse_formula("H2O")
+    aw1 = parse_formula("B4C")
     print(aw1)
 
     # tmp = write_spec_file("tmp.spec",numpy.zeros((4,100)),titles=['x','y','z','more z'])
@@ -1824,14 +1826,15 @@ if __name__ == "__main__":
     #
     # f1f2_calc*
     #
-    for i in range(12):
-        tmp = f1f2_calc(26,[10000.0,22000],F=i)
-        print(">>>>>>>>>>>>>>F=%d, Z=26,f1f2_calc="%i,tmp,tmp.shape )
-
-    for i in range(12):
-        # print(">>>>>>>>>>>>>>F=%d, f1f2_calc_mix="%i, f1f2_calc_mix("SiC",[10000.0],F=i,density=3.21))
-        print(">>>>>>>>>>>>>>F=%d, f1f2_calc_mix for H2O="%i, f1f2_calc_mix("H2O",[10000.0],F=i,density=1.0))
+    # for i in range(12):
+    #     tmp = f1f2_calc(26,[10000.0,22000],F=i)
+    #     print(">>>>>>>>>>>>>>F=%d, Z=26,f1f2_calc="%i,tmp,tmp.shape )
+    #
+    # for i in range(12):
+    #     # print(">>>>>>>>>>>>>>F=%d, f1f2_calc_mix="%i, f1f2_calc_mix("SiC",[10000.0],F=i,density=3.21))
+    #     print(">>>>>>>>>>>>>>F=%d, f1f2_calc_mix for H2O="%i, f1f2_calc_mix("H2O",[10000.0],F=i,density=1.0))
 
+    # assert( numpy.abs( tmp1[0] - 8.7654751491065230e-07) < 1e-9  )
 
 
 
