@@ -10,7 +10,7 @@ from PyQt5 import QtGui, QtWidgets
 from PyQt5.QtCore import QRect
 from PyQt5.QtWidgets import QApplication
 
-from matplotlib.backends.backend_qt4agg import FigureCanvasQTAgg as FigureCanvas
+from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 
 from srxraylib.plot import gol
 
@@ -23,6 +23,7 @@ from oasys.widgets.exchange import DataExchangeObject
 from oasys.util.oasys_util import EmittingStream
 
 from orangecontrib.xoppy.util.xoppy_util import xoppy_doc, XoppyPlot
+from orangecontrib.xoppy.util.python_script import PythonScript
 
 class XoppyWidget(widget.OWWidget):
     author = "Manuel Sanchez del Rio, Luca Rebuffi"
@@ -44,7 +45,7 @@ class XoppyWidget(widget.OWWidget):
 
     want_main_area = 1
 
-    def __init__(self):
+    def __init__(self,show_script_tab=False):
         super().__init__()
 
         self.runaction = OWAction("Compute", self)
@@ -78,8 +79,9 @@ class XoppyWidget(widget.OWWidget):
 
         self.main_tabs = oasysgui.tabWidget(self.mainArea)
         plot_tab = oasysgui.createTabPage(self.main_tabs, "Results")
-        out_tab = oasysgui.createTabPage(self.main_tabs, "Output")
 
+
+        #results tab
         view_box = oasysgui.widgetBox(plot_tab, "Results Options", addSpace=False, orientation="horizontal")
         view_box_1 = oasysgui.widgetBox(view_box, "", addSpace=False, orientation="vertical", width=350)
 
@@ -88,19 +90,36 @@ class XoppyWidget(widget.OWWidget):
                                             items=["No", "Yes"],
                                             callback=self.set_ViewType, sendSelectedValue=False, orientation="horizontal")
 
-        self.tab = []
         self.tabs = oasysgui.tabWidget(plot_tab)
 
+        self.tab = []
         self.initializeTabs()
 
+        #output tab
+        out_tab = oasysgui.createTabPage(self.main_tabs, "Output")
         self.xoppy_output = QtWidgets.QTextEdit()
         self.xoppy_output.setReadOnly(True)
 
         out_box = gui.widgetBox(out_tab, "System Output", addSpace=True, orientation="horizontal")
         out_box.layout().addWidget(self.xoppy_output)
 
-        self.xoppy_output.setFixedHeight(600)
-        self.xoppy_output.setFixedWidth(600)
+        # self.xoppy_output.setFixedHeight(600)
+        # self.xoppy_output.setFixedWidth(600)
+
+        if show_script_tab:
+
+            # script tab
+            script_tab = oasysgui.createTabPage(self.main_tabs, "Script")
+            self.xoppy_script = PythonScript()
+            self.xoppy_script.code_area.setFixedHeight(400)
+
+            script_box = gui.widgetBox(script_tab, "Python script", addSpace=True, orientation="horizontal")
+            script_box.layout().addWidget(self.xoppy_script)
+
+            # self.xoppy_script.setFixedHeight(600)
+            # self.xoppy_script.setFixedWidth(600)
+
+        self.current_tab = -1
 
         gui.rubber(self.mainArea)
 
@@ -127,6 +146,9 @@ class XoppyWidget(widget.OWWidget):
             tab.setFixedHeight(self.IMAGE_HEIGHT)
             tab.setFixedWidth(self.IMAGE_WIDTH)
 
+    def getDefaultPlotTabIndex(self):
+        return -1
+
     def getTitles(self):
         return ["Calculation Result"]
 
@@ -160,6 +182,8 @@ class XoppyWidget(widget.OWWidget):
     def plot_results(self, calculated_data, progressBarValue=80):
         if not self.view_type == 0:
             if not calculated_data is None:
+                current_index = self.tabs.currentIndex()
+
                 self.view_type_combo.setEnabled(False)
 
                 xoppy_data = calculated_data.get_content("xoppy_data")
@@ -186,13 +210,23 @@ class XoppyWidget(widget.OWWidget):
                                         log_x=log_x,
                                         log_y=log_y)
 
-                        self.tabs.setCurrentIndex(index)
+                        # self.tabs.setCurrentIndex(index)
                     except Exception as e:
                         self.view_type_combo.setEnabled(True)
 
                         raise Exception("Data not plottable: bad content\n" + str(e))
 
                 self.view_type_combo.setEnabled(True)
+
+                try:
+                    self.tabs.setCurrentIndex(current_index)
+                except:
+                    if self.getDefaultPlotTabIndex() == -1:
+                        self.tabs.setCurrentIndex(len(titles) - 1)
+                    else:
+                        self.tabs.setCurrentIndex(self.getDefaultPlotTabIndex())
+
+
             else:
                 raise Exception("Empty Data")
 
@@ -226,14 +260,12 @@ class XoppyWidget(widget.OWWidget):
                                                                       roi=False,
                                                                       mask=False,
                                                                       fit=False)
-
             self.plot_canvas[plot_canvas_index].setDefaultPlotLines(True)
             self.plot_canvas[plot_canvas_index].setActiveCurveColor(color="#00008B")
             self.plot_canvas[plot_canvas_index].setGraphXLabel(xtitle)
             self.plot_canvas[plot_canvas_index].setGraphYLabel(ytitle)
 
             self.tab[tabs_canvas_index].layout().addWidget(self.plot_canvas[plot_canvas_index])
-
         XoppyPlot.plot_histo(self.plot_canvas[plot_canvas_index], x, y, title, xtitle, ytitle, color, replace)
 
         self.plot_canvas[plot_canvas_index].setXAxisLogarithmic(log_x)
@@ -250,6 +282,7 @@ class XoppyWidget(widget.OWWidget):
             else:
                 self.plot_canvas[plot_canvas_index].setGraphYLimits(min(y), max(y)*1.01)
 
+
         self.progressBarSet(progressBarValue)
 
     def plot_data1D(self, dataX, dataY, tabs_canvas_index, plot_canvas_index, title="", xtitle="", ytitle=""):
@@ -258,7 +291,7 @@ class XoppyWidget(widget.OWWidget):
 
         self.plot_canvas[plot_canvas_index] = oasysgui.plotWindow()
 
-        self.plot_canvas[plot_canvas_index].addCurve(dataX, dataY,)
+        self.plot_canvas[plot_canvas_index].addCurve(dataX, dataY)
 
         self.plot_canvas[plot_canvas_index].resetZoom()
         self.plot_canvas[plot_canvas_index].setXAxisAutoScale(True)
@@ -273,8 +306,6 @@ class XoppyWidget(widget.OWWidget):
 
         self.tab[tabs_canvas_index].layout().addWidget(self.plot_canvas[plot_canvas_index])
 
-
-
     def plot_data2D(self, data2D, dataX, dataY, tabs_canvas_index, plot_canvas_index, title="", xtitle="", ytitle="", mode=2):
 
         for i in range(1+self.tab[tabs_canvas_index].layout().count()):
@@ -326,7 +357,7 @@ class XoppyWidget(widget.OWWidget):
                 #silx 0.4.0
                 self.plot_canvas[plot_canvas_index].getMaskAction().setVisible(False)
                 self.plot_canvas[plot_canvas_index].getRoiAction().setVisible(False)
-                self.plot_canvas[plot_canvas_index].getColormapAction().setVisible(False)
+                self.plot_canvas[plot_canvas_index].getColormapAction().setVisible(True)
                 self.plot_canvas[plot_canvas_index].setKeepDataAspectRatio(False)
 
 
@@ -340,12 +371,6 @@ class XoppyWidget(widget.OWWidget):
 
                 self.plot_canvas[plot_canvas_index].setActiveImage("zio billy")
 
-                # COLOR TABLE
-                from matplotlib.image import AxesImage
-                image = AxesImage(self.plot_canvas[plot_canvas_index]._backend.ax)
-                image.set_data(numpy.array(data_to_plot))
-                self.plot_canvas[plot_canvas_index]._backend.fig.colorbar(image, ax=self.plot_canvas[plot_canvas_index]._backend.ax)
-
             self.plot_canvas[plot_canvas_index].setGraphXLabel(xtitle)
             self.plot_canvas[plot_canvas_index].setGraphYLabel(ytitle)
             self.plot_canvas[plot_canvas_index].setGraphTitle(title)
@@ -367,14 +392,20 @@ class XoppyWidget(widget.OWWidget):
         ymin = numpy.min(dataY)
         ymax = numpy.max(dataY)
 
-        origin = (xmin, ymin)
-        scale = (abs((xmax-xmin)/len(dataX)), abs((ymax-ymin)/len(dataY)))
 
+        stepX = dataX[1]-dataX[0]
+        stepY = dataY[1]-dataY[0]
+        if len(dataE) > 1: stepE = dataE[1]-dataE[0]
+        else: stepE = 1.0
 
+        if stepE == 0.0: stepE = 1.0
+        if stepX == 0.0: stepX = 1.0
+        if stepY == 0.0: stepY = 1.0
+
+        dim0_calib = (dataE[0],stepE)
+        dim1_calib = (ymin, stepY)
+        dim2_calib = (xmin, stepX)
 
-        dim0_calib = (dataE[0],dataE[1]-dataE[0])
-        dim1_calib = (ymin, dataY[1]-dataY[0])
-        dim2_calib = (xmin, dataX[1]-dataX[0])
 
         data_to_plot = numpy.swapaxes(data3D,1,2)
 
@@ -442,7 +473,19 @@ class XoppyWidget(widget.OWWidget):
          self.resetSettings()
 
     def help1(self):
-        xoppy_doc(self.get_help_name())
+
+        import os
+        from orangecontrib.xoppy.util.text_window import TextWindow
+        from orangecontrib.xoppy.util.xoppy_util import locations
+
+        home_doc = locations.home_doc()
+
+        filename1 = os.path.join(home_doc, self.get_help_name() + '.txt')
+
+        TextWindow(file=filename1,parent=self)
+
+
+
 
     def get_help_name(self):
         raise Exception("This method should be reimplementd in subclasses!")
